/*
アイデア・ハック!! Arduinoで遊ぼう（10）
「「もぐらたたきみたいな（？）ゲーム」」
									2014.04.16　三月兎
									URL:robot-fan.net
 */
#include "pitches.h"

//-----------------------
// 定数の定義
//-----------------------
const int BZ = 2;            	         //ブザーの出力ピン

const int LED_COUNT = 5;                 //LEDの数
const int LED[LED_COUNT] = {7,8,9,10,11};//各LEDのピン番号
const int VALUE[LED_COUNT] = {200,400,600,800,1000};
                                         //LEDに対応したセンサー値
const int SENSOR = A5;            	 //センサーの入力ピン
const int SENSOR_OFF = 100;              //センサーOFFの値
//-----------------------
// グローバル変数の定義
//-----------------------
int G_ledno = -1;//選択したLED（未選択の値：-1）

void setup() {
        //ブザーを出力モードに設定
	pinMode(BZ, OUTPUT);
        //全てのLEDを出力モードに設定
        for(int i = 0; i < LED_COUNT; i++) {
  	  pinMode(LED[i], OUTPUT);
        }
        //シリアル通信を開始
//        Serial.begin(9600);
        //乱数の初期設定に未接続ピンのノイズを利用
        randomSeed(analogRead(A0));
        //スタート音
        bz_start();
}

void loop() {
  if (G_ledno < 0) {
      //当たりの番号を決める
      G_ledno = random(LED_COUNT);
      //当たりのLEDを点灯する
      digitalWrite(LED[G_ledno],HIGH);
    }
    //センサーを押した位置を取得する
    int sensorno = get_sensorno();
    if(sensorno != -999) {
      //センサーを押した
      if (G_ledno == sensorno) {
        //当たりのLEDを消灯する
        digitalWrite(LED[G_ledno],LOW);
        //当たり！
        toneMelody(NOTE_G6,4);
        G_ledno = -1;
      }
      else {
        //はずれ
        toneMelody(NOTE_D4,4);
      }
      //センサーを離すまで待つ
      while(get_sensorno() != -999);
    }
}

//-----------------------------------
//センサーを押した位置を取得する
//-----------------------------------
int get_sensorno() {
  int sensorno = -1;
  int sensorVal = analogRead(SENSOR);    //センサーの値を読む
//  Serial.println(sensorVal);
  if(sensorVal < SENSOR_OFF) {
    //センサーOFF
    sensorno = -999;
  }
  else {
    //センサー値が安定するのを待つ
    delay(100);
    sensorVal = analogRead(SENSOR);
    //センサーを押した位置を判定（しきい値±50）
    for(int i = 0; i < LED_COUNT; i++) {
      if(sensorVal >= VALUE[i] - 50 && sensorVal <= VALUE[i] + 50) {
        sensorno = i;
        break;
      }
    }
  }
  return(sensorno);
}
//-----------------------
// スタート
//-----------------------
void bz_start(){
  int melody[] = {NOTE_C5, NOTE_D5, NOTE_E5, NOTE_G5, 0, NOTE_B4, NOTE_G5};
  int noteDurations[] = {8,8,8,8,8,8,4};
  for (int i = 0; i < 7; i++) {
    toneMelody(melody[i], noteDurations[i]);
  }
}
//-----------------------------------
//指定した音階と長さでブザーを鳴らす
// note:音階  duration:長さ
//-----------------------------------
void toneMelody(int note, int duration){
  int noteDuration = 1000 / duration;    //音の長さを決める
  tone(BZ, note);                        //ブザーを指定周波数
  delay(noteDuration);                   //指定時間 鳴らす

  //音の切れ目を作る
  noteDuration = noteDuration * 0.1;    //長さを決めてる
  noTone(BZ);                           //ブザーへの出力を止める
  delay(noteDuration);                  //指定時間保つ
}

